Index — tox 2.9.0rc2.dev63 documentation

# Index

A | B | C | D | E | F | G | I | L | M | N | O | P | R | S | T | U | V | W

## A

add_argument() (tox.config.Parser method) add_testenv_attribute() (tox.config.Parser method) add_testenv_attribute_obj() (tox.config.Parser method) | alwayscopy=True|False configuration value args_are_paths=BOOL configuration value

## B

basepython=NAME-OR-PATH configuration value

## C

changedir=path configuration value commands=ARGVLIST configuration value Config (class in tox.config) config (tox.config.TestenvConfig attribute) configuration value alwayscopy=True|False args_are_paths=BOOL basepython=NAME-OR-PATH changedir=path commands=ARGVLIST deps=MULTI-LINE-LIST description=SINGLE-LINE-TEXT downloadcache=path envdir envlist=CSV envlogdir=path envtmpdir=path extras=MULTI-LINE-LIST ignore_errors=True|False(default) ignore_outcome=BOOL indexserver install_command=ARGV list_dependencies_command passenv=SPACE-SEPARATED-GLOBNAMES pip_pre=True|False(default) platform=REGEX recreate=True|False(default) setenv=MULTI-LINE-LIST sitepackages=True|False skip_install=BOOL skip_missing_interpreters=BOOL usedevelop=BOOL whitelist_externals=MULTI-LINE-LIST

## D

deps=MULTI-LINE-LIST configuration value description=SINGLE-LINE-TEXT configuration value | downloadcache=path configuration value

## E

envconfigs (tox.config.Config attribute) envdir configuration value envlist=CSV configuration value envlogdir=path configuration value | envname (tox.config.TestenvConfig attribute) envpython (tox.config.TestenvConfig attribute) envtmpdir=path configuration value extras=MULTI-LINE-LIST configuration value

## F

factors (tox.config.TestenvConfig attribute)

## G

get_envbindir() (tox.config.TestenvConfig method) get_envpython() (tox.config.TestenvConfig method) get_envsitepackagesdir() (tox.config.TestenvConfig method) | get_installpkg_path() (tox.session.Session method) getcommandpath() (tox.venv.VirtualEnv method) getvenv() (tox.session.Session method)

## I

ignore_errors=True|False(default) configuration value ignore_outcome=BOOL configuration value | indexserver configuration value install_command=ARGV configuration value installpkg() (tox.session.Session method)

## L

list_dependencies_command configuration value

## M

missing_subs (tox.config.TestenvConfig attribute)

## N

name (tox.venv.VirtualEnv attribute)

## O

option (tox.config.Config attribute)

## P

Parser (class in tox.config) passenv=SPACE-SEPARATED-GLOBNAMES configuration value path (tox.venv.VirtualEnv attribute) pip_pre=True|False(default) configuration value | platform=REGEX configuration value Python Enhancement Proposals PEP 386 python_info (tox.config.TestenvConfig attribute)

## R

recreate=True|False(default) configuration value

## S

Session (class in tox.session) setenv=MULTI-LINE-LIST configuration value sitepackages=True|False configuration value | skip_install=BOOL configuration value skip_missing_interpreters=BOOL configuration value

## T

TestenvConfig (class in tox.config) tox.hookspecs (module) tox_addoption() (in module tox.hookspecs) tox_configure() (in module tox.hookspecs) tox_get_python_executable() (in module tox.hookspecs) | tox_runtest() (in module tox.hookspecs) tox_runtest_post() (in module tox.hookspecs) tox_runtest_pre() (in module tox.hookspecs) tox_testenv_create() (in module tox.hookspecs) tox_testenv_install_deps() (in module tox.hookspecs)

## U

update() (tox.venv.VirtualEnv method) | usedevelop=BOOL configuration value

## V

VirtualEnv (class in tox.venv)

## W

whitelist_externals=MULTI-LINE-LIST configuration value